<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ml">
<context>
    <name>ControlCenter</name>
    <message>
        <location filename="../qml/ControlCenter.qml" line="188"/>
        <source>Wi-Fi</source>
        <translation>വൈഫൈ</translation>
    </message>
    <message>
        <location filename="../qml/ControlCenter.qml" line="191"/>
        <location filename="../qml/ControlCenter.qml" line="214"/>
        <source>On</source>
        <translation>ഓൺ</translation>
    </message>
    <message>
        <location filename="../qml/ControlCenter.qml" line="191"/>
        <location filename="../qml/ControlCenter.qml" line="203"/>
        <location filename="../qml/ControlCenter.qml" line="214"/>
        <source>Off</source>
        <translation>ഓഫ്</translation>
    </message>
    <message>
        <location filename="../qml/ControlCenter.qml" line="202"/>
        <source>Bluetooth</source>
        <translation>ബ്ലൂടൂത്ത്</translation>
    </message>
    <message>
        <location filename="../qml/ControlCenter.qml" line="213"/>
        <source>Dark Mode</source>
        <translation>ഇരുണ്ട മോഡ്</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="71"/>
        <source>Close</source>
        <translation>അടയ്ക്കുക</translation>
    </message>
</context>
</TS>
